@@ -40,7 +40,7 @@
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 '''
 
-__version__ = "3.0.4"
+__version__ = "3.1.0"
 
 import syslog
 import os
@@ -367,8 +367,12 @@ def _rejectmessage(result, type, info, ip, recipient, configData):
         rejectdefer = "rejected"
     elif result[3] == 'defer':
         rejectdefer = "deferred"
-    url = ("http://www.openspf.net/Why?s={0};id={1};ip={2};r={3}"
-              .format(type, info, ip, recipient))
+    rurl = configData.get('Reason_URL')
+    if rurl:
+        url = rurl.format(type, info, ip, recipient)
+    else:
+        url = ("http://www.openspf.net/Why?s={0};id={1};ip={2};r={3}"
+               .format(type, info, ip, recipient))
     msg = configData.get('Reason_Message')
     return msg.format(
             rejectdefer=rejectdefer,
@@ -564,6 +568,7 @@ def _spfcheck(data, instance_dict, configData, peruser, peruserconfigData):  #{{
             if debugLevel >= 2:
                 syslog.syslog('spfcheck: pyspf result: "%s"' % str(helo_result))
             if HELO_reject == 'Null' and sender:
+                helo_result[0] = 'None'
                 helo_result.append('dunno')
             else:
                 for poss_actions in helo_resultpolicy:
