@@ -45,6 +45,7 @@ defaultConfigData = {
         'Whitelist_Lookup_Time' : 10,
         'Void_Limit' : 2,
         'Reason_Message' : 'Message {rejectdefer} due to: {spf}. Please see {url}',
+        'Reason_URL' : 'http://www.openspf.net/Why?s={0};id={1};ip={2};r={3}',
         'No_Mail' : False,
         'Mock' : False,
         'QueueID' : True,
@@ -150,6 +151,7 @@ def _readConfigFile(path, configData = None, configGlobal = {}):
             'Whitelist_Lookup_Time': int,
             'Void_Limit'  : int,
             'Reason_Message' : str,
+            'Reason_URL' : str,
             'Mock' : bool,
             # For milter front end
             'Socket': str,
@@ -183,7 +185,7 @@ def _readConfigFile(path, configData = None, configGlobal = {}):
         if debugLevel >= 3: syslog.syslog(str(line))
         if not line: continue
         data = [q.strip() for q in line.split('=')]
-        if len(data) != 2:
+        if len(data) != 2 and data[0] != 'Reason_URL':
             if len(data) == 1:
                 if debugLevel >= 1:
                     syslog.syslog('Configuration item "%s" not defined in file "%s"'
@@ -192,6 +194,13 @@ def _readConfigFile(path, configData = None, configGlobal = {}):
                 syslog.syslog('ERROR parsing line "%s" from file "%s"'
                     % ( line, path ))
             continue
+        elif data[0] == 'Reason_URL':  # Reason_URL is the only item where = is valid within the config setting.
+            x = ''
+            for e in data[1:-1]:
+                x += e + '='
+            x += data[-1]
+            data = [data[0], x]
+            syslog.syslog(str(data))
         name, value = data
 
         #  check validity of name
